@@ -1,7 +1,7 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright (c) 2013-2021 Fraunhofer FKIE
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -33,32 +33,32 @@ import os
 from lxml import etree as ET
 from ..linter import ERROR, WARNING, NOTICE
 from ..cmake import argparse as cmake_argparse
-from ..util import enumerate_package_files
+from ..util import enumerate_package_files, is_active_depend
+from ..environment import PackageType
 from .misc import project
 
 
 def depends(linter):
     def on_init(info):
-        info.buildtool_dep = {dep.name for dep in info.manifest.buildtool_depends if dep.evaluated_condition}
-        info.build_dep = {dep.name for dep in info.manifest.build_depends if dep.evaluated_condition}
+        info.buildtool_dep = {dep.name for dep in info.manifest.buildtool_depends if is_active_depend(dep)}
+        info.build_dep = {dep.name for dep in info.manifest.build_depends if is_active_depend(dep)}
         info.export_dep = set()
         info.exec_dep = set()
         if info.manifest.package_format > 1:
-            deps = {dep.name for dep in info.manifest.build_export_depends if dep.evaluated_condition}
+            deps = {dep.name for dep in info.manifest.build_export_depends if is_active_depend(dep)}
             info.export_dep.update(deps)
-            deps = {dep.name for dep in info.manifest.buildtool_export_depends if dep.evaluated_condition}
+            deps = {dep.name for dep in info.manifest.buildtool_export_depends if is_active_depend(dep)}
             info.export_dep.update(deps)
-            deps = {dep.name for dep in info.manifest.exec_depends if dep.evaluated_condition}
+            deps = {dep.name for dep in info.manifest.exec_depends if is_active_depend(dep)}
             info.exec_dep.update(deps)
         if info.manifest.package_format < 2:
             deps = {dep.name for dep in info.manifest.run_depends}
             info.export_dep.update(deps)
             info.exec_dep.update(deps)
-        info.test_dep = {dep.name for dep in info.manifest.test_depends if dep.evaluated_condition}
-        if info.env.ok:
-            for pkg in info.buildtool_dep | info.build_dep | info.export_dep | info.exec_dep | info.test_dep:
-                if not info.env.is_known_pkg(pkg):
-                    info.report(ERROR, "UNKNOWN_PACKAGE", pkg=pkg, file_location=("package.xml", 0))
+        info.test_dep = {dep.name for dep in info.manifest.test_depends if is_active_depend(dep)}
+        for pkg in info.buildtool_dep | info.build_dep | info.export_dep | info.exec_dep | info.test_dep:
+            if info.env.get_package_type(pkg) == PackageType.UNKNOWN:
+                info.report(ERROR, "UNKNOWN_PACKAGE", pkg=pkg, file_location=("package.xml", 0))
         if info.manifest.is_metapackage() and info.build_dep:
             info.report(ERROR, "INVALID_META_DEPEND", type="build", file_location=("package.xml", 0))
         if info.manifest.is_metapackage() and info.test_dep:
@@ -73,28 +73,58 @@ def launch_depends(linter):
     # not litter the log with warnings about missing exec_depends if these are used in launch files
     essential_packages = set(["rosbag", "rosnode", "rosservice", "rostopic"])
 
+    def on_init(info):
+        info.test_launch_files = set()
+
+    def on_add_rostest(info, cmd, args):
+        launch_file = args[0 if cmd == "add_rostest" else 1]
+        if not info.is_existing_path(launch_file, check=os.path.isfile):
+            info.report(ERROR, "MISSING_FILE", cmd=cmd, file=launch_file)
+        info.test_launch_files.add(info.source_relative_path(launch_file))
+
     def on_final(info):
         for dirpath, filename in enumerate_package_files(info.path):
             if filename.lower().endswith(".launch"):
                 full_filename = os.path.join(dirpath, filename)
                 src_filename = os.path.relpath(full_filename, info.path)
+                exec_dep_type = "exec" if info.manifest.package_format > 1 else "run"
+                is_test_launch_file = src_filename in info.test_launch_files
                 with open(full_filename, "rb") as f:
                     content = f.read()
                     try:
                         root = ET.fromstring(content)
                         for node in root.getiterator():
-                            if node.tag is not ET.Comment:
+                            if node.tag is ET.Comment:
+                                args = (node.text or "").split()
+                                if args[0] == "catkin_lint:" and args[1] in ["ignore_once", "ignore", "report"]:
+                                    msg_ids = set([a.upper() for a in args[2:]])
+                                    if args[1] == "ignore":
+                                        info.ignore_message_ids |= msg_ids
+                                    if args[1] == "report":
+                                        info.ignore_message_ids -= msg_ids
+                                    if args[1] == "ignore_once":
+                                        info.ignore_message_ids_once |= msg_ids
+                            else:
+                                relevant_deps = info.exec_dep
+                                dep_type = exec_dep_type
+                                if node.tag == "test" or is_test_launch_file:
+                                    relevant_deps |= info.test_dep
+                                    dep_type = "test"
                                 pkg = node.get("pkg")
-                                if pkg is not None and pkg != info.manifest.name and info.env.is_catkin_pkg(pkg) and pkg not in info.exec_dep and pkg not in essential_packages:
-                                    info.report(WARNING, "LAUNCH_DEPEND", type="exec" if info.manifest.package_format > 1 else "run", pkg=pkg, file_location=(src_filename, node.sourceline or 0))
+                                if pkg is not None and pkg != info.manifest.name and info.env.get_package_type(pkg) == PackageType.CATKIN and pkg not in relevant_deps and pkg not in essential_packages:
+                                    info.report(WARNING, "LAUNCH_DEPEND", type=dep_type, pkg=pkg, file_location=(src_filename, node.sourceline or 0))
                                 for mo in re.finditer(r"\$\(find\s+([^<>)]+)\)", "<>".join(node.values() + [node.text or "", node.tail or ""])):
                                     pkg = mo.group(1)
-                                    if pkg is not None and pkg != info.manifest.name and info.env.is_catkin_pkg(pkg) and pkg not in info.exec_dep and pkg not in essential_packages:
-                                        info.report(WARNING, "LAUNCH_DEPEND", type="exec" if info.manifest.package_format > 1 else "run", pkg=pkg, file_location=(src_filename, node.sourceline or 0))
+                                    if pkg is not None and pkg != info.manifest.name and info.env.get_package_type(pkg) == PackageType.CATKIN and pkg not in relevant_deps and pkg not in essential_packages:
+                                        info.report(WARNING, "LAUNCH_DEPEND", type=dep_type, pkg=pkg, file_location=(src_filename, node.sourceline or 0))
+                                info.ignore_message_ids_once.clear()
                     except (ET.Error, ValueError) as err:
                         info.report(WARNING, "PARSE_ERROR", msg=str(err), file_location=(src_filename, 0))
 
     linter.require(depends)
+    linter.add_init_hook(on_init)
+    linter.add_command_hook("add_rostest", on_add_rostest)
+    linter.add_command_hook("add_rostest_gtest", on_add_rostest)
     linter.add_final_hook(on_final)
 
 
