@@ -1,7 +1,7 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright (c) 2013-2021 Fraunhofer FKIE
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -37,6 +37,7 @@ from fnmatch import fnmatch
 from copy import copy
 from .cmake import ParserContext, argparse as cmake_argparse, CMakeSyntaxError
 from .diagnostics import msg, add_user_defined_msg
+from .util import abspath
 
 ERROR = 0
 WARNING = 1
@@ -668,7 +669,7 @@ class CMakeLinter(object):
                 self._get_overrides(info, config["*"])
             if manifest.name in config:
                 self._get_overrides(info, config[manifest.name])
-        info.path = os.path.abspath(path)
+        info.path = abspath(path)
         info.manifest = manifest
         info.conditionals = []
         info.var = {
@@ -706,7 +707,7 @@ class CMakeLinter(object):
             self._parse_file(info, os.path.join(path, "CMakeLists.txt"))
             for cb in self._final_hooks:
                 cb(info)
-        except IOError as err:
+        except (OSError, IOError) as err:
             info.report(ERROR, "OS_ERROR", msg=str(err))
         self.messages += info.messages
         self.ignored_messages += info.ignored_messages
