@@ -1,7 +1,7 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright (c) 2013-2021 Fraunhofer FKIE
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -33,6 +33,28 @@ import re
 import tempfile
 
 
+def getcwd():
+    # os.getcwd() will always report the real path, even though
+    # we would prefer the logical path if the directory path
+    # contains symlinks. Unfortunately, there is no portable way
+    # to do this, so we rely on the environment variable PWD,
+    # which is set by most shells. If PWD is unset or stale, we
+    # fall back to os.getcwd()
+    actual_pwd = os.getcwd()
+    if "PWD" in os.environ:
+        logical_pwd = os.environ.get("PWD")
+        if os.path.realpath(logical_pwd) == actual_pwd:
+            return logical_pwd
+    return actual_pwd
+
+
+def abspath(path):
+    # os.path.abspath calls os.getcwd(), but we would prefer the
+    # logical path if available, so we reimplement it in terms of
+    # getcwd() above.
+    return os.path.normpath(os.path.join(getcwd(), path))
+
+
 def word_split(s):
     ws = re.compile(r"(\W|_)+|(?<=[^A-Z])(?=[A-Z])|(?<=\w)(?=[A-Z][a-z])")
     mo = ws.search(s)
@@ -77,6 +99,12 @@ def is_sorted(lst, key=lambda x, y: x < y):
     return True
 
 
+def is_active_depend(d):
+    if hasattr(d, "evaluated_condition"):
+        return d.evaluated_condition
+    return True
+
+
 def enumerate_package_files(rootdir, catkin_ignore=True, ignore_dot=True, ignore_unimportant=True):
     for dirpath, dirnames, filenames in os.walk(rootdir, topdown=True):
         if "CATKIN_IGNORE" in filenames and catkin_ignore:
