@@ -1,7 +1,7 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright (c) 2013-2021 Fraunhofer FKIE
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -62,6 +62,10 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all("command($<0:ignore_me>)"),
             [("command", [])]
         )
+        self.assertEqual(
+            self.parse_all("command($<BUILD_INTERFACE:use_me>)"),
+            [("command", ["use_me"])]
+        )
 
     def test_command(self):
         """Test CMake parser command parsing"""
@@ -94,6 +98,10 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all('cmd("string that spans\nmultiple lines")'),
             [("cmd", ['string that spans\nmultiple lines'])]
         )
+        self.assertEqual(
+            self.parse_all('cmd("string with \\\nline continuation")'),
+            [("cmd", ['string with line continuation'])]
+        )
         self.assertEqual(
             self.parse_all('cmd("\\\\"\\")'),
             [("cmd", ['\\', '"'])]
@@ -244,6 +252,10 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all("cmd(one;two three)"),
             [("cmd", ["one", "two", "three"])]
         )
+        self.assertEqual(
+            self.parse_all("cmd(one\\;two three)"),
+            [("cmd", ["one;two", "three"])]
+        )
         self.assertEqual(
             self.parse_all('cmd("one;two" three)'),
             [("cmd", ["one;two", "three"])]
@@ -256,6 +268,26 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all('cmd(one;"two;three")'),
             [("cmd", ["one", "two;three"])]
         )
+        self.assertEqual(
+            self.parse_all('cmd(one [[two]] three)'),
+            [("cmd", ["one", "two", "three"])]
+        )
+        self.assertEqual(
+            self.parse_all('cmd(one [=[two]]]=] three)'),
+            [("cmd", ["one", "two]]", "three"])]
+        )
+        self.assertEqual(
+            self.parse_all('cmd(one [=[two]==]]=] three)'),
+            [("cmd", ["one", "two]==]", "three"])]
+        )
+        self.assertEqual(
+            self.parse_all('cmd(one [[\ntwo]] three)'),
+            [("cmd", ["one", "two", "three"])]
+        )
+        self.assertEqual(
+            self.parse_all('cmd(one [=[ two [==[ ]=] [=[three ]==] ]=])'),
+            [("cmd", ["one", " two [==[ ", "three ]==] "])]
+        )
         self.assertEqual(
             self.parse_all('if(NOT (A OR B)) endif()'),
             [("if", ["NOT", "(", "A", "OR", "B", ")"]), ("endif", [])]
@@ -320,6 +352,10 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all('cmd(\\${args})', var={"args": "fail"}),
             [("cmd", ["${args}"])]
         )
+        self.assertEqual(
+            self.parse_all('cmd([[${args}]])', var={"args": "fail"}),
+            [("cmd", ["${args}"])]
+        )
         self.assertEqual(
             self.parse_all('cmd(${args})', var={"args": "\\\\"}),
             [("cmd", ["\\\\"])]
@@ -483,6 +519,16 @@ class CMakeParserTest(unittest.TestCase):
             """),
             [("cmd", ["one", "two", "three"])]
         )
+        self.assertEqual(
+            self.parse_all("""\
+            # initial comment
+            cmd(one #[[ bracket comment ]=]
+            fail # embedded comment ]]
+            two
+            )
+            """),
+            [("cmd", ["one", "two"])]
+        )
 
     def test_line_numbering(self):
         """Test CMake parser line numbering"""
